@@ -14,7 +14,7 @@
 #' versus the wickets taken
 #'
 #' @usage
-#' bowlerWktsPredict(df, name)
+#' bowlerWktsPredict(df, name,dateRange)
 #'
 #' @param df
 #' Data frame
@@ -22,6 +22,9 @@
 #' @param name
 #' Name of bowler
 #'
+#' @param dateRange
+#' Date interval to consider
+#'
 #' @return None
 #' @references
 #' \url{https://cricsheet.org/}\cr
@@ -36,7 +39,7 @@
 #' \dontrun{
 #' # Get the data frame for RA Jadeja
 #' jadeja1 <- getDeliveryWickets(team="India",name="Jadeja",save=FALSE)
-#' bowlerWktsPredict(jadeja1,"RA Jadeja")
+#' bowlerWktsPredict(jadeja1,"RA Jadeja",dateRange)
 #' }
 #'
 #' @seealso
@@ -48,8 +51,9 @@
 #' @export
 #'
 
-bowlerWktsPredict <- function(df,name){
+bowlerWktsPredict <- function(df,name,dateRange){
     rpart = NULL
+    df=df %>% filter(date >= dateRange[1] & date <= dateRange[2])
     print(names(df))
     m <-rpart(wicketNo~delivery,data=df)
     atitle <- paste(name,"- No of deliveries to Wicket")
