@@ -66,10 +66,9 @@ convertYaml2RDataframeT20 <- function(yamlFile,sourceDir=".",targetDir="."){
     a <- yaml.load_file(pth)
     # This is a temporary change.
     # Removing elements of Players,Registry and balls per over from yaml file
-    a[[2]][[10]] <- NULL #Players
-    a[[2]][[10]] <- NULL #Registry
-    a[[2]][[1]] <- NULL  #balls per over
-
+    a[[2]][['players']] <- NULL #Players
+    a[[2]][['registry']] <- NULL #Registry
+    a[[2]][['balls_per_over']] <- NULL  #balls per over
     # Cast as data frame for easy processing
     tryCatch(b <- as.data.frame(a),
              error = function(e) {
